<?php

namespace Skynettechnologies\Aioa\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Skynettechnologies\Aioa\Interfaces\AioaRepositoryInterface;
use Skynettechnologies\Aioa\Repositories\Eloquent\Filters\AioaPublicFilter;
use Skynettechnologies\Aioa\Repositories\Eloquent\Presenters\AioaListPresenter;

class AioaPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        AioaRepositoryInterface $aioa
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('skynettechnologies.aioa.modules'), 'aioa', guard_url('aioa'));
        $this->repository = $aioa;
    }

    /**
     * Show aioa's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(AioaPublicFilter::class)
            ->setPresenter(AioaListPresenter::class)
            ->select('aioas.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('aioa::aioa.names'))
            ->view('aioa::public.aioa.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show aioa.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('aioa::aioa.name'))
            ->view('aioa::public.aioa.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
