<?php

namespace Skynettechnologies\Aioa\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Skynettechnologies\Aioa\Forms\Aioa as AioaForm;
use Skynettechnologies\Aioa\Http\Requests\AioaRequest;
use Skynettechnologies\Aioa\Interfaces\AioaRepositoryInterface;
use Skynettechnologies\Aioa\Repositories\Eloquent\Filters\AioaResourceFilter;
use Skynettechnologies\Aioa\Repositories\Eloquent\Presenters\AioaListPresenter;

/**
 * Resource controller class for aioa.
 */
class AioaResourceController extends BaseController
{

    /**
     * Initialize aioa resource controller.
     *
     *
     * @return null
     */
    public function __construct(AioaRepositoryInterface $aioa)
    {
        parent::__construct();
        $this->form = AioaForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('skynettechnologies.aioa.modules'), 'aioa', guard_url('aioa'));
        $this->repository = $aioa;
    }

    /**
     * Display a list of aioa.
     *
     * @return Response
     */
    public function index(AioaRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(AioaResourceFilter::class)
            ->setPresenter(AioaListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('aioa::aioa.names'))
            ->view('aioa::aioa.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display aioa.
     *
     * @param Request $request
     * @param Model   $aioa
     *
     * @return Response
     */
    public function show(AioaRequest $request, AioaRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('aioa::aioa.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('aioa::aioa.show')
            ->output();
    }

    /**
     * Show the form for creating a new aioa.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(AioaRequest $request, AioaRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('aioa::aioa.name'))
            ->view('aioa::aioa.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new aioa.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AioaRequest $request, AioaRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('aioa::aioa.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('aioa/aioa/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/aioa/aioa'))
                ->redirect();
        }

    }

    /**
     * Show aioa for editing.
     *
     * @param Request $request
     * @param Model   $aioa
     *
     * @return Response
     */
    public function edit(AioaRequest $request, AioaRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('aioa::aioa.name'))
            ->view('aioa::aioa.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the aioa.
     *
     * @param Request $request
     * @param Model   $aioa
     *
     * @return Response
     */
    public function update(AioaRequest $request, AioaRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('aioa::aioa.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('aioa/aioa/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('aioa/aioa/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the aioa.
     *
     * @param Model   $aioa
     *
     * @return Response
     */
    public function destroy(AioaRequest $request, AioaRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('aioa::aioa.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('aioa/aioa/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('aioa/aioa/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
