<?php

namespace Skynettechnologies\Aioa\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Skynettechnologies\Aioa\Models\Aioa;

class AioaPolicy
{

    /**
     * Determine if the given user can view the aioa.
     *
     * @param UserPolicyInterface $authUser
     * @param Aioa $aioa
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Aioa $aioa)
    {
        if ($authUser->canDo('aioa.aioa.view') && $authUser->isAdmin()) {
            return true;
        }

        return $aioa->user_id == user_id() && $aioa->user_type == user_type();
    }

    /**
     * Determine if the given user can create a aioa.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('aioa.aioa.create');
    }

    /**
     * Determine if the given user can update the given aioa.
     *
     * @param UserPolicyInterface $authUser
     * @param Aioa $aioa
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Aioa $aioa)
    {
        if ($authUser->canDo('aioa.aioa.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $aioa->user_id == user_id() && $aioa->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given aioa.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Aioa $aioa)
    {
        return $aioa->user_id == user_id() && $aioa->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given aioa.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Aioa $aioa)
    {
        if ($authUser->canDo('aioa.aioa.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given aioa.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Aioa $aioa)
    {
        if ($authUser->canDo('aioa.aioa.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
